package com.bwie.house.Scheduling;


import com.bwie.common.domain.Loan;
import com.bwie.common.domain.User;
import com.bwie.common.domain.vo.LoanVo;
import com.bwie.house.mapper.HouseMapper;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.List;
import java.util.UUID;


@Component
@Log4j2
public class ApplyLoan {
        @Resource
        private HouseMapper houseMapper;
        @Resource
        private RabbitTemplate rabbitTemplate;



    @Scheduled(cron = "0/30 * * * * ?")
    public void SyncBlog2EsPerMinute(){
        System.out.println("定时器执行完毕");
        List<LoanVo> loanVos = houseMapper.selLoanListApply();
        for (LoanVo loanVo : loanVos) {
            User user = houseMapper.selUserById(loanVo.getUserId());
            BigDecimal time = new BigDecimal(loanVo.getTime());
            BigDecimal money = loanVo.getLoanMoney().divide(time, 2, RoundingMode.HALF_UP);
            BigDecimal creditScore = new BigDecimal(user.getCreditScore()*10);
            int i = creditScore.compareTo(money);
            if (i>0){
                houseMapper.updStatePass(loanVo.getLoanId());
            }else {
                houseMapper.updStateBack(loanVo.getLoanId());
                rabbitTemplate.convertAndSend("sendSms",user.getUserPhone(),message -> {
                    message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                    return message;
                });
            }
            System.out.println("定时器执行完毕");
        }

    }
}
