package com.bwie.house.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.Cycle;
import com.bwie.common.domain.House;
import com.bwie.common.domain.Loan;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.HouseReq;
import com.bwie.common.domain.request.OtherCycle;
import com.bwie.common.domain.response.LoanDTO;
import com.bwie.common.domain.vo.LoanVo;
import com.bwie.common.utils.JwtUtils;
import com.bwie.house.mapper.HouseMapper;
import com.bwie.house.service.HouseService;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.List;

@Service
public class HouseServiceImpl implements HouseService {
    @Resource
    private HouseMapper houseMapper;


    @Resource
    private StringRedisTemplate stringRedisTemplate;

    @Resource
    private HttpServletRequest httpServletRequest;
    @Override
    public List<House> selHouse(HouseReq req) {
        return houseMapper.selHouse(req);
    }

    @Override
    public House selHouseById(Integer houseId) {
            return houseMapper.selHouseById(houseId);
    }

    @Override
    public List<Cycle>  selCycleList() {
        return houseMapper.selCycleList();
    }

    @Override
    public BigDecimal selHouseRealMoney(OtherCycle otherCycle) {
        Cycle cycle = houseMapper.selCycleById(otherCycle.getCycleId());
        BigDecimal realMoney = houseMapper.selHouseRealMoney(otherCycle.getHouseId(), cycle.getTime());
        return realMoney;
    }




    @Override
    public BigDecimal selHouseAfterMoney(OtherCycle otherCycle) {
        String token = httpServletRequest.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String s = stringRedisTemplate.opsForValue().get(JwtConstants.USER_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);
        Loan loan = houseMapper.selLoanRecord(user.getUserId());
        if (loan==null){
            Cycle cycle = houseMapper.selCycleById(otherCycle.getCycleId());
            BigDecimal afterMoney = houseMapper.selHouseAfterMoney(otherCycle.getHouseId(), cycle.getTime(), cycle.getDiscount());
            return afterMoney;
        }
        return null;
    }

    @Override
    public Integer insertLoan(LoanDTO loanDTO) {
        Loan loan = new Loan();
        String token = httpServletRequest.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String s = stringRedisTemplate.opsForValue().get(JwtConstants.USER_KEY + userKey);
        User user = JSONObject.parseObject(s, User.class);
        loan.setUserId(user.getUserId());
        loan.setHouseId(loanDTO.getHouseId());
        loan.setCycleId(loanDTO.getCycleId());
        if (loanDTO.getAfterMoney()!=null){
            loan.setLoanMoney(loanDTO.getAfterMoney());
        }else {
            loan.setLoanMoney(loanDTO.getRealMoney());
        }
        Integer i = houseMapper.insertLoan(loan);
        return i;
    }

    @Override
    public List<LoanVo> selLoanList() {
        return houseMapper.selLoanList();
    }
}
